RemoteReadyToReceiveError

Enum RemoteReadyToReceiveError 

pub enum RemoteReadyToReceiveError {
    NoRemoteConnectedNoDSR,
    NoRemoteConnectedNoCD,
    RemoteNotClearToSend,
}
Errors indicating the device is not ready to send data.

Variants



NoRemoteConnectedNoDSR

There is no remote connected (DSR is not raised).



NoRemoteConnectedNoCD

There is no remote connected (CD is not raised).



RemoteNotClearToSend

A remote endpoint is present but has not asserted readiness to receive more data (yet).

This can for example mean that it is still processing input data.