pub enum WordLength {
FiveBits,
SixBits,
SevenBits,
EightBits,
}Expand description
The length of words for the transmission and reception in LCR.
This type is a convenient and non-ABI compatible abstraction. ABI
compatibility is given via WordLength::from_raw_bits and
WordLength::to_raw_bits.
Variants
FiveBits
5-bit words.
SixBits
6-bit words.
SevenBits
7-bit words.
EightBits
8-bit words (recommended default).
Implementations
Sourceimpl WordLength
impl WordLength
Sourcepub const fn from_raw_bits(bits: u8) -> Self
pub const fn from_raw_bits(bits: u8) -> Self
Translates the raw encoding into the corresponding value.
This function operates on the value as-is and does not perform any shifting bits.
Sourcepub const fn to_raw_bits(self) -> u8
pub const fn to_raw_bits(self) -> u8
Translates the value into the corresponding raw encoding.
This function operates on the value as-is and does not perform any shifting bits.
Sourcepub const fn from_integer(value: u8) -> Self
pub const fn from_integer(value: u8) -> Self
Try to create the type from an integer representation of the word length.
Falling back to Self::EightBits on invalid values.
Sourcepub const fn to_integer(self) -> u32
pub const fn to_integer(self) -> u32
Returns the value as corresponding integer.